; Copyright (c) 2004-2010, Stubbe F. Hviid
;   All rights reserved
;+
; NAME:
;   PRO build_ris_cal_archive, ris_archive_root
;
; PURPOSE:
;   Automatically generate the secondary OSIRIS calibrated archive
;
; CATEGORY:
;   Osiris Archiving
;
; CALLING SEQUENCE:
;  PRO build_ris_cal_archive, ris_archive_root
;
; INPUTS:
;   ris_archive_root:		Path to the root of the secondary OSIRIS archive
;
; KEYWORD PARAMETERS:
;	None
;
; OUTPUTS:
;   Nothing
;
; RESTRICTIONS:
;   Input sorce data must follow the OSIRIS archive structure
;
; EXAMPLE:
;   build_ris_cal_archive, 'c:\temp\'
;
; MODIFICATION HISTORY:
;   Written by:  Stubbe F. Hviid   21/4-2009
;-

PRO find_level1_data_directories, root_dir, rel_dir, dir_list

	print, 'root_dir = ' + root_dir
	print, 'rel_dir = ' + rel_dir


	dirs = file_search(root_dir + '\' + rel_dir + '\*', /TEST_DIRECTORY)

	for i=0, n_elements(dirs)-1 do begin
		if dirs[i] ne '' AND dirs[i] ne '.' AND dirs[i] ne '..' then begin
			fd = p_parse_file_path(dirs[i])
			nreldir = rel_dir + '\' + fd.filename
			find_level1_data_directories, root_dir, nreldir, dir_list
		endif
	endfor

	files = file_search(root_dir + '\' + rel_dir + '\*.IMG', /TEST_REGULAR)

	if files[0] ne '' then begin
		if n_elements(dir_list) eq 0 then dir_list = [rel_dir] else dir_list = [dir_list, rel_dir]
	endif

END

PRO build_ris_cal_archive, ris_archive_root, _EXTRA=_EXTRA

	ris_archive_root = strtrim(ris_archive_root, 2)

	; handle cygwin input path format
	if strmid(ris_archive_root, 0, 10) eq '/cygdrive/' then begin
		t = strmid(ris_archive_root, 10, 1) + ':' + strmid(ris_archive_root, 11)
		ris_archive_root = t
	endif


	mission_phases = FILE_SEARCH(ris_archive_root + '/*', /TEST_DIRECTORY)

	for i=0, n_elements(mission_phases)-1 do begin
		mfs = p_parse_file_path(mission_phases[i])

		print, ''
		print, '+---------------------------------------------------------------------'
		print, '|  Processing Mission Phase: ' + mfs.name
		print, '|  ' + systime()

		mission_phase_root = ris_archive_root + '\' + mfs.name

		date_segments = FILE_SEARCH(mission_phase_root + '/*', /TEST_DIRECTORY)

		for j=0, n_elements(date_segments)-1 do begin
			if date_segments[j] ne '' then begin
				dfs = p_parse_file_path(date_segments[j])

				dfs_root = mission_phase_root + '\' + dfs.name
				if file_test(dfs_root + '\pds\level1') then begin
					print, '         - Processing Directory: ' + dfs_root + '\pds\level1'
					osiris_calibrate_dir, dfs_root + '\pds\level1', dfs_root + '\pds\level2', dfs_root + '\pds\level3', $
										 JPEG_LEVEL2_DIR=dfs_root + '\jpeg\level2', $
										 THUMB_LEVEL2_DIR=dfs_root + '\thumbnail\level2', $
										 JPEG_LEVEL3_DIR=dfs_root + '\jpeg\level3', $
										 THUMB_LEVEL3_DIR=dfs_root + '\thumbnail\level3', $
					                      _EXTRA=_EXTRA
				endif
			endif
		endfor
		print, '|  ' + systime()
		print, '|  Done Processing Mission Phase: ' + mfs.name
		print, '+---------------------------------------------------------------------'
		print, ''
	endfor
END
